@@ -57,34 +57,100 @@ class VarLenArray:
         return self.__class__(self.array[idx])
 
 
+class NpDataClass:
+
+    @classmethod
+    def single_entry(cls, *args, **kwargs):
+        obj = cls._single_entry(*args, **kwargs)
+        cls._implicit_format_conversion(obj)
+        return obj
+
+    @classmethod
+    def _implicit_format_conversion(cls, obj):
+        for field in dataclasses.fields(obj):
+            setattr(obj, field.name, np.asanyarray(getattr(obj, field.name)))
+
+    def _assert_same_lens(self):
+        t = shallow_tuple(self)
+        l = len(t[0])
+        for p in t:
+            assert len(p) == l, f"All fields in a npdataclass need to be of the same length: {t}"
+
+    @classmethod
+    def empty(cls):
+        return cls(*([] for field in dataclasses.fields(cls)))
+
+    def astype(self, new_class):
+        my_fields = {f.name for f in dataclasses.fields(self)}
+        new_fields = {f.name for f in dataclasses.fields(new_class)}
+        assert all(
+            field.name in my_fields for field in dataclasses.fields(new_class)
+        ), (my_fields, new_fields)
+        return new_class(**{name: getattr(self, name) for name in new_fields})
+
+    def shallow_tuple(self):
+        return tuple(
+            getattr(self, field.name) for field in dataclasses.fields(self)
+        )
+
+    def __getitem__(self, idx):
+        cls = self.single_entry if isinstance(idx, Number) else self.__class__
+        return cls(*[f[idx] for f in shallow_tuple(self)])
+
+    def __len__(self):
+        return len(shallow_tuple(self)[0])
+
+    def __array_function__(self, func, types, args, kwargs):
+        if func == np.concatenate:
+            objects = args[0]
+            tuples = [shallow_tuple(o) for o in objects]
+            return self.__class__(*(np.concatenate(list(t)) for t in zip(*tuples)))
+        if func == np.equal:
+            one, other = args
+            return all(
+                np.equal(s, o)
+                for s, o in zip(shallow_tuple(one), shallow_tuple(other))
+            )
+
+        return NotImplemented
+
+    def __iter__(self):
+        return (self.single_entry(*comb) for comb in zip(*shallow_tuple(self)))
+
+    @classmethod
+    def stack_with_ragged(cls, objects):
+        tuples = [shallow_tuple(o) for o in objects]
+        new_entries = [list(t) for t in zip(*tuples)]
+        new_entries = (
+            RaggedArray(np.concatenate(e), RaggedShape([len(t) for t in e]))
+            if hasattr(e[0], "__len__") and not all(len(i) == len(e[0]) for i in e)
+            else np.concatenate(e).reshape(-1, len(e[0]))
+            for e in new_entries
+        )
+        ret = cls(*new_entries)
+        return ret
+
+
 def npdataclass(base_class):
     new_class = dataclasses.dataclass(base_class)
 
-    class FinalClass(new_class):
+    class FinalClass(new_class, NpDataClass):
         _single_entry = new_class
 
         def __init__(self, *args, **kwargs):
             super().__init__(*args, **kwargs)
             self._implicit_format_conversion(self)
             self._assert_same_lens()
-    
-        @classmethod
-        def single_entry(cls, *args, **kwargs):
-            obj = cls._single_entry(*args, **kwargs)
-            cls._implicit_format_conversion(obj)
-            return obj
 
-        @classmethod
-        def _implicit_format_conversion(cls, obj):
-            for field in dataclasses.fields(obj):
-                setattr(obj, field.name, np.asanyarray(getattr(obj, field.name)))
-    
-        def _assert_same_lens(self):
-            t = shallow_tuple(self)
-            l = len(t[0])
-            for p in t:
-                assert len(p) == l, f"All fields in a npdataclass need to be of the same length: {t}"
-    
+        def __eq__(self, other):
+            for s, o in zip(shallow_tuple(self), shallow_tuple(other)):
+                if not s.shape == o.shape:
+                    return False
+                if not np.all(np.equal(s, o)):
+                    return False
+            return True
+            # return all(np.all(np.equal(s, o)) for s, o in zip(self.shallow_tuple(), other.shallow_tuple()))
+
         def __str__(self):
             lines = []
             col_length = 25
@@ -99,70 +165,10 @@ def npdataclass(base_class):
                 lines.append("".join(f"{str(col)[:col_length-2]:>{col_length}}" for col in cols))
             return "\n".join(lines)
 
+    
         __repr__ = __str__
 
-        @classmethod
-        def empty(cls):
-            return cls(*(np.array([]) for field in dataclasses.fields(cls)))
-    
-        def astype(self, new_class):
-            my_fields = {f.name for f in dataclasses.fields(self)}
-            new_fields = {f.name for f in dataclasses.fields(new_class)}
-            assert all(
-                field.name in my_fields for field in dataclasses.fields(new_class)
-            ), (my_fields, new_fields)
-            return new_class(**{name: getattr(self, name) for name in new_fields})
-    
-        def shallow_tuple(self):
-            return tuple(
-                getattr(self, field.name) for field in dataclasses.fields(self)
-            )
-    
-        def __getitem__(self, idx):
-            cls = self.single_entry if isinstance(idx, Number) else self.__class__
-            return cls(*[f[idx] for f in shallow_tuple(self)])
-    
-        def __len__(self):
-            return len(shallow_tuple(self)[0])
-    
-        def __eq__(self, other):
-            for s, o in zip(shallow_tuple(self), shallow_tuple(other)):
-                if not s.shape == o.shape:
-                    return False
-                if not np.all(np.equal(s, o)):
-                    return False
-            return True
-            # return all(np.all(np.equal(s, o)) for s, o in zip(self.shallow_tuple(), other.shallow_tuple()))
-    
-        def __array_function__(self, func, types, args, kwargs):
-            if func == np.concatenate:
-                objects = args[0]
-                tuples = [shallow_tuple(o) for o in objects]
-                return self.__class__(*(np.concatenate(list(t)) for t in zip(*tuples)))
-            if func == np.equal:
-                one, other = args
-                return all(
-                    np.equal(s, o)
-                    for s, o in zip(shallow_tuple(one), shallow_tuple(other))
-                )
-    
-            return NotImplemented
-    
-        def __iter__(self):
-            return (self.single_entry(*comb) for comb in zip(*shallow_tuple(self)))
-    
-        @classmethod
-        def stack_with_ragged(cls, objects):
-            tuples = [shallow_tuple(o) for o in objects]
-            new_entries = [list(t) for t in zip(*tuples)]
-            new_entries = (
-                RaggedArray(np.concatenate(e), RaggedShape([len(t) for t in e]))
-                if hasattr(e[0], "__len__") and not all(len(i) == len(e[0]) for i in e)
-                else np.concatenate(e).reshape(-1, len(e[0]))
-                for e in new_entries
-            )
-            ret = cls(*new_entries)
-            return ret
+
 
     FinalClass.__name__ = base_class.__name__
     FinalClass.__qualname__ = base_class.__qualname__
